Module: Google::Cloud::AutoML

Defined in:
lib/google/cloud/automl.rb,
lib/google/cloud/automl/helpers.rb,
lib/google/cloud/automl/version.rb

Constant Summary collapse

VERSION =
"2.0.3"

Class Method Summary collapse

Class Method Details

.automl(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for AutoML.

By default, this returns an instance of Google::Cloud::AutoML::V1::AutoML::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the AutoML service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the AutoML service. You can determine whether the method will succeed by calling automl_available?.

About AutoML

AutoML Server API.

The resource names are assigned by the server. The server never reuses names that it has created after the resources with those names are deleted.

An ID of a resource is the last element of the item's resource name. For projects/{project_id}/locations/{location_id}/datasets/{dataset_id}, then the id for the item is {dataset_id}.

Currently the only supported location_id is "us-central1".

On any input that is documented to expect a string parameter in snake_case or dash-case, either of those cases is accepted.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



161
162
163
164
165
166
167
168
169
170
171
# File 'lib/google/cloud/automl.rb', line 161

def self.automl version: :v1, transport: :grpc, &block
  require "google/cloud/automl/#{version.to_s.downcase}"

  package_name = Google::Cloud::AutoML
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AutoML.const_get(package_name).const_get(:AutoML)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.automl_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the AutoML service is supported by the current client. If true, you can retrieve a client object by calling automl. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the AutoML service, or if the versioned client gem needs an update to support the AutoML service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/google/cloud/automl.rb', line 185

def self.automl_available? version: :v1, transport: :grpc
  require "google/cloud/automl/#{version.to_s.downcase}"
  package_name = Google::Cloud::AutoML
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::AutoML.const_get package_name
  return false unless service_module.const_defined? :AutoML
  service_module = service_module.const_get :AutoML
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.configure {|::Google::Cloud.configure.automl| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-automl library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



232
233
234
235
236
# File 'lib/google/cloud/automl.rb', line 232

def self.configure
  yield ::Google::Cloud.configure.automl if block_given?

  ::Google::Cloud.configure.automl
end

.prediction_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for PredictionService.

By default, this returns an instance of Google::Cloud::AutoML::V1::PredictionService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the PredictionService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the PredictionService service. You can determine whether the method will succeed by calling prediction_service_available?.

About PredictionService

AutoML Prediction API.

On any input that is documented to expect a string parameter in snake_case or dash-case, either of those cases is accepted.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



78
79
80
81
82
83
84
85
86
87
88
# File 'lib/google/cloud/automl.rb', line 78

def self.prediction_service version: :v1, transport: :grpc, &block
  require "google/cloud/automl/#{version.to_s.downcase}"

  package_name = Google::Cloud::AutoML
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AutoML.const_get(package_name).const_get(:PredictionService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.prediction_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the PredictionService service is supported by the current client. If true, you can retrieve a client object by calling prediction_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the PredictionService service, or if the versioned client gem needs an update to support the PredictionService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/google/cloud/automl.rb', line 102

def self.prediction_service_available? version: :v1, transport: :grpc
  require "google/cloud/automl/#{version.to_s.downcase}"
  package_name = Google::Cloud::AutoML
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::AutoML.const_get package_name
  return false unless service_module.const_defined? :PredictionService
  service_module = service_module.const_get :PredictionService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end